<?php
/*
* $Id: st_swcleaner.php
* $Loc: /includes/modules/store/
*
* Name: SloppyWordsCleaner
* Version: 3.4.4
* Release Date: 2024-06-02
* Author: Rainer Schmied
* 	 phoenixcartaddonsaddons.com / raiwa@phoenixcartaddons.com
*
* License: Released under the GNU General Public License
*
* Comments: Author: [Rainer Schmied @raiwa]
* Author URI: [www.phoenixcartaddons.com]
* 
* CE Phoenix, E-Commerce made Easy
* https://phoenixcart.org
* 
* Copyright (c) 2021 Phoenix Cart
* 
* 
*/

  class st_swcleaner extends abstract_executable_module {

    const CONFIG_KEY_BASE = 'MODULE_STORE_SWCLEANER_';

    public function __construct() {
      parent::__construct(__FILE__);

      $this->description .= '<p>by @raiwa <u><a target="_blank" href="http://www.oscaddons.com">www.oscaddons.com</a></u></p>';
      if (!file_exists(DIR_FS_CATALOG . 'templates/' . TEMPLATE_SELECTION . '/includes/hooks/shop/siteWide/swc_hooks.php')) {
        $this->enabled = false;
        $this->description = '<div class="alert alert-danger" role="alert">' .
                                 MODULE_STORE_SWCLEANER_HOOK_WARNING .
                             '</div>' .
                             $this->description;
      }
    }

    function execute() {

    }

    protected function get_parameters() {
      return [
        static::CONFIG_KEY_BASE . 'VERSION_INSTALLED' => [
          'title' => 'Current Version',
          'value' => '3.4.3',
          'desc' => 'Version info. It is read only',
          'set_func' => 'st_swcleaner::readonly(',
        ],
        static::CONFIG_KEY_BASE . 'STATUS' => [
          'title' => 'Enable Sloppy Words Cleaner Module',
          'value' => 'True',
          'desc' => 'Do you want to add the Sloppy Words Cleaner Module to your shop?',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        static::CONFIG_KEY_BASE . 'PAGES' => [
          'title' => 'Pages',
          'value' => 'create_account.php;account_pwa.php;account_edit.php;address_book_process.php;address_book_process_nif.php;checkout_shipping_address.php;checkout_payment_address.php;ext/modules/payment/paypal/express.php;ext/modules/payment/paypal/express_payflow.php',
          'desc' => 'The pages where to use the Sloppy words cleaner.',
          'set_func' => "page_selection::_edit_pages(",
          'use_func' => 'page_selection::_show_pages',
        ],
        static::CONFIG_KEY_BASE . 'CONVERT_PAIRS' => [
          'title' => 'Convert words',
          'value' => 'Saint:St,Sainte:Ste,Saints:Sts,Saintes:Stes,MacKintosh:Mackintosh,Decicco:DeCicco,Degennaro:DeGennaro,Delorenzo:DeLorenzo,Dicosmo:DiCosmo,Dimaggio:DiMaggio,Dimarco:DiMarco,Dimichele:DiMichele,Dipaolo:DiPaolo,Dipietro:DiPietro',
          'desc' => 'List of whole words which are conversion exceptions. Must be listed like these examples, Ex.: Saint:St,Saintes:Stes.',
          'set_func' => 'st_swcleaner::shorten_string(',
        ],
        static::CONFIG_KEY_BASE . 'EXCEPTIONS' => [
          'title' => 'Exception names',
          'value' => 'De Quincey,La Rochefoucauld',
          'desc' => 'List of whole words which are conversion exceptions and will not be filtered. Must be listed as coma separated array, Ex.: McDonald,MacDonald,Macdonald,Mcdonald.',
          'set_func' => 'st_swcleaner::shorten_string(',
        ],
        static::CONFIG_KEY_BASE . 'PREFIXES' => [
          'title' => 'Prefixes',
          'value' => 'Mc,Mac,l\',d\',O\',Dell\'',
          'desc' => 'List of Prefixes which should be followed by Upper case. Comma separated list.',
          'set_func' => 'st_swcleaner::shorten_string(',
        ],
        static::CONFIG_KEY_BASE . 'SUFFIXES' => [
          'title' => 'Suffixes',
          'value' => '\'S',
          'desc' => 'List of Suffixes which should be by Upper case. Comma separated list.',
          'set_func' => 'st_swcleaner::shorten_string(',
        ],
        static::CONFIG_KEY_BASE . 'ALL_LOWER_NAME' => [
          'title' => 'All lower case Names',
          'value' => 'De La,De Las,Del,De Los,De,Y,I,Du,Dos,Do,Der,Von,Vom,Auf,Zu,Genannt,Gen,Or,And,Und,D\',L\'',
          'desc' => 'List of words which should be all lower case in Names. Comma separated list.',
          'set_func' => 'st_swcleaner::shorten_string(',
        ],
        static::CONFIG_KEY_BASE . 'ALL_UPPER_NAME' => [
          'title' => 'All upper case Names',
          'value' => '',
          'desc' => 'List of words which should be all upper case in Names. Comma separated list.',
          'set_func' => 'st_swcleaner::shorten_string(',
        ],
        static::CONFIG_KEY_BASE . 'ALL_LOWER' => [
          'title' => 'All lower case',
          'value' => 'À,A,And,As,Am,An,Au,Aux,By,D,Da,De,Des,Del,Du,Der,Die,Das,Bei,En,Et,In,L,Le,La,Les,Of,Or,Ou,Sous,Sur,To,Von,Y',
          'desc' => 'List of words which should be all lower case in all other fields. Comma separated list.',
          'set_func' => 'st_swcleaner::shorten_string(',
        ],
        static::CONFIG_KEY_BASE . 'ALL_UPPER' => [
          'title' => 'All upper case',
          'value' => 'Aly,Anx,Apt,Ave,Bch,Blvd,Bldg,Bp,bp,Bsmt,Byu,Ch,Cors,Cswy,Cr,Crk,Crt,Cts,Cv,Cvs,Est,Ests,Expy,Frnt,Fl,Frks,Fwy,Gdn,Gtwy,Hbr,Hbrs,Hts,Hwy,Ii,Iii,Iv,Jct,Jcts,Lk,Lks,Ln,Ldg,Mnt,Mnr,Mnrs,Msn,Mtwy,Mtn,Mtns,Ne,Nw,Pkwy,Pl,Pln,Plns,Ph,Po,Pob,P.o.b.,P.O.b.,p.O.b.,p.o.B.,p.O.B.,Rm,Rr,Se,Skwy,Smt,Sw,Sta,Ste,Sq,Ter,Tpke,Trpk,Trlr,Trl,Trwy,Vl,Vlg,Vlgs,Vly,Vlys,Vi,Vii,Viii,Xi,Xing,Xrd',
          'desc' => 'List of words which should be all upper case in all other fields. Comma separated list.',
          'set_func' => 'st_swcleaner::shorten_string(',
        ],
        static::CONFIG_KEY_BASE . 'CLEAN_COMPANY' => [
          'title' => 'Enable Company filter',
          'value' => 'False',
          'desc' => 'Do you want to filter the Company entrance? This option is not recommended, Company names have a wide varity of upper/lower case spelling.',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        static::CONFIG_KEY_BASE . 'ALL_LOWER_COMPANY' => [
          'title' => 'All lower case Company',
          'value' => 'De La,De Las,Del,De Los,Der,Van De,Van Der,Vit De,Von,Or,And,A,And,As,By,In,Of,Or,To,The',
          'desc' => 'List of words which should be all lower case in Company Names. Comma separated list.',
          'set_func' => 'st_swcleaner::shorten_string(',
        ],
        static::CONFIG_KEY_BASE . 'ALL_UPPER_COMPANY' => [
          'title' => 'All upper case Company',
          'value' => 'S.a.,S.l.,3m,Aa,Aaa,Ab,Abc,Abn,Aflac,Ag,Akso,Amd,Aol,Basf,Bb,Bbb,Bmw,Ca,Cbs,Cc,Ccc,Csx,Cvs,Dd,Ddd,Dec,Dhl,Ee,Eee,Ff,Fff,Ftd,Gg,Ggg,Ge,Gm,Gnc,Hh,Hhh,Hsbc,Ii,Iii,Ibm,Jj,Jjj,Jal,Jbl,Jvc,Kk,Kkk,Kfc,Klm,Lcl,Ll,Lll,Ltd,Lg,Mbna,Mips,Mm,Mmm,Mci,Mgm,Mvc,Ncr,Nn,Nnn,Nec,Oo,Ooo,Pmc,Pp,Ppp,Pg&e,Qq,Qqq,Qantas,Qvc,Rca,Reo,Rr,Rrr,Rsa,Sa,Saab,Sap,Sas,Scb,Sco,Sega,Skf,Snk,Ss,Sss,Stx,Tcl,Tcs,Tnt,Tt,Ttt,Twa,Uu,Uuu,Ua,Ubl,Ubs,Ul,Ups,Usx,Vv,Vvv,Vw,Ww,Www,Xx,Xxx,Yy,Yyy,Zz,Zzz',
          'desc' => 'List of words which should be all upper case in Company Names. Comma separated list.',
          'set_func' => 'st_swcleaner::shorten_string(',
        ],
        static::CONFIG_KEY_BASE . 'REMOVE_SPECIALS' => [
          'title' => 'Convert specials',
          'value' => 'False',
          'desc' => 'Do you want to convert all special characters?<br>Êžšķūņrūķīšáàî > Ezskunrukisaai',
          'set_func' => "Config::select_one(['True', 'False'], ",
        ],
        static::CONFIG_KEY_BASE . 'SORT_ORDER' => [
          'title' => 'Sort Order',
          'value' => '0',
          'desc' => 'Sort order of display. Must be first, readonly.',
          'set_func' => 'st_swcleaner::readonly(',
        ],
      ];
    }

    public static function readonly($value) {
      return $value;
    }

    public static function shorten_string($text) {
      return substr ($text, 0, 100);
    }

  }
